@@ -7,14 +7,12 @@ EOF = function(x, how = c("spatial", "temporal"), returnPredictions = TRUE, ...)
 		pr = prcomp(x, ...)
 		if (! returnPredictions)
 			return(pr)
-		x = data.frame(predict(pr))
-		x = addAttrToGeom(sp, x, TRUE)
+		x = addAttrToGeom(sp, data.frame(predict(pr)), TRUE)
 	} else if (how[1] == "temporal") {
 		pr = prcomp(x, ...)
 		if (! returnPredictions)
 			return(pr)
-		x = data.frame(predict(pr))
-		x = xts(x, index)
+		x = xts(data.frame(predict(pr)), index)
 	} else
 		stop("unknown mode: use spatial or temporal")
 	names(x) = paste("EOF", 1:ncol(x), sep="")
