@@ -1,5 +1,5 @@
 stConstruct = function(x, space, time, SpatialObj = NULL, 
-		TimeObj = NULL, crs = CRS(as.character(NA)), interval) {
+		TimeObj = NULL, crs = CRS(as.character(NA)), interval, endTime) {
 	if (is(x, "xts")) {
 		stopifnot(ncol(x) == length(space))
 		return(STFDF(space, index(x), data.frame(x = as.vector(t(x)))))
@@ -8,7 +8,9 @@ stConstruct = function(x, space, time, SpatialObj = NULL,
 		x = data.frame(x)
 	stopifnot(is(x, "data.frame"))
 	#stopifnot(isIndex(space) && isIndex(time)) 
-	if (length(space) > 1 && length(time) == 1) { 
+# old line:	if (length(space) > 1 && length(time) == 1) { 
+  # BG: univariate time-wide tables get stuck here otherwise
+	if (length(space) > 1 && length(time) == 1 && !is.list(time)) { # BG 
 		# long format; space indicates columns with points, coordinates
 			n = names(x)
 		if (is.character(space))
@@ -22,10 +24,12 @@ stConstruct = function(x, space, time, SpatialObj = NULL,
 		else
 			ti = time
 		time = xts(1:nrow(x), x[[ti]])
-		if (!missing(interval))
-			timeIsInterval(time) = interval
+		if (!missing(interval) && isTRUE(interval))
+			endTime = delta(time)
+		else
+			endTime = as.POSIXct(index(time))
 		x = x[-c(si, ti)]
-		return(STIDF(sp, time, x))
+		return(STIDF(sp, time, x, endTime))
 	} else if (length(space) == 1 && length(time) == 1) {
 		# long format, space indicates index of SpatialObj:
 		stopifnot(!is.null(SpatialObj))
@@ -34,17 +38,25 @@ stConstruct = function(x, space, time, SpatialObj = NULL,
 			# stop("space/time combinations not complete")
 			# why not try Irregular?
 			time = xts(1:nrow(x), x[,time])
-			if (!missing(interval))
-				timeIsInterval(time) = interval
-			return(STIDF(SpatialObj, time, x))
+			if (missing(endTime)) {
+				endTime = index(time)
+				if (!missing(interval) && interval)
+					endTime = delta(time)
+			}
+			return(STIDF(SpatialObj, time, x, endTime))
 		} else {
 			sut = sort(unique(x[,time]))
 			tm = xts(1:length(sut), sut)
-			if (!missing(interval))
-				timeIsInterval(tm) = interval
+			if (missing(endTime)) {
+				endTime = delta(tm)
+				if (!missing(interval) && !interval)
+					endTime = as.POSIXct(index(tm))
+			}
+			#if (!missing(interval))
+			#	timeIsInterval(tm) = interval
 			sp = as.character(sort(unique(x[,space])))
 			return(STFDF(SpatialObj[sp], tm, 
-				x[order(x[,time],as.character(x[,space])),]))
+				x[order(x[,time],as.character(x[,space])),], endTime))
 		}
 	} else if (is.list(time)) {  
 		# time-wide table; space coords or SpatialObj
@@ -53,17 +65,23 @@ stConstruct = function(x, space, time, SpatialObj = NULL,
 			SpatialObj = SpatialPoints(x[,space], CRS)
 		else if (missing(SpatialObj))
 			SpatialObj = space
-		if (! missing(interval))
-			timeIsInterval(TimeObj) = interval
 		xx = data.frame(lapply(time, function(g) stack(x[g])$values))
-		return(STFDF(SpatialObj, TimeObj, xx))
+		if (missing(endTime)) {
+			endTime = delta(TimeObj)
+			if (!missing(interval) && !interval)
+				endTime = index(TimeObj)
+		}
+		return(STFDF(SpatialObj, TimeObj, xx, endTime))
 	} else if (is.list(space)) { 
 		# space-wide table:
 		xx = data.frame(lapply(space, function(g) as.vector(t(x[g]))))
-		if (!missing(interval))
-			timeIsInterval(time) = interval
+		if (missing(endTime)) {
+			endTime = delta(time)
+			if (!missing(interval) && !interval)
+				endTime = as.POSIXct(index(time))
+		}
 		return(STFDF(SpatialObj, time, 
-			data.frame(values = as.vector(t(xx)))))
+			data.frame(values = as.vector(t(xx))), endTime))
 	} 
 	stop("unknown parameter combination")
 }
